entities/__init__.py
changeset 10095 200bd6a601dc
parent 10019 c4a5865989ee
child 10251 2daa5c6dea4d
child 10396 33e44293b0eb
--- a/entities/__init__.py	Wed May 14 15:05:31 2014 +0200
+++ b/entities/__init__.py	Thu Nov 06 14:35:25 2014 +0100
@@ -34,8 +34,8 @@
 
     @classproperty
     def cw_etype(cls):
-        """entity type as a string"""
-        return cls.__regid__
+        """entity type as a unicode string"""
+        return unicode(cls.__regid__)
 
     @classmethod
     def cw_create_url(cls, req, **kwargs):